summaryrefslogtreecommitdiffstats
path: root/pkg/config/user_config.go
diff options
context:
space:
mode:
Diffstat (limited to 'pkg/config/user_config.go')
-rw-r--r--pkg/config/user_config.go5
1 files changed, 4 insertions, 1 deletions
diff --git a/pkg/config/user_config.go b/pkg/config/user_config.go
index 38259f6f2..ea079948e 100644
--- a/pkg/config/user_config.go
+++ b/pkg/config/user_config.go
@@ -252,7 +252,10 @@ type KeybindingSubmodulesConfig struct {
// OSConfig contains config on the level of the os
type OSConfig struct {
- // EditCommand is the command for editing a file
+ // Editor is the command for editing a file
+ Editor string `yaml:"editor,omitempty"`
+
+ // EditCommand is the command template for editing a file
EditCommand string `yaml:"editCommand,omitempty"`
// OpenCommand is the command for opening a file